"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transformMap = exports.mapProductProps = exports.mapEventProps = exports.mapEventNames = void 0;

var _reactNativeBranch = require("react-native-branch");

const mapEventNames = {
  'Product Clicked': _reactNativeBranch.BranchEvent.ViewItem,
  'Product Viewed': _reactNativeBranch.BranchEvent.ViewItem,
  'Product Added': _reactNativeBranch.BranchEvent.AddToCart,
  'Product Reviewed': _reactNativeBranch.BranchEvent.Rate,
  'Checkout Started': _reactNativeBranch.BranchEvent.InitiatePurchase,
  'Promotion Viewed': _reactNativeBranch.BranchEvent.ViewAd,
  'Payment Info Entered': _reactNativeBranch.BranchEvent.AddPaymentInfo,
  'Order Completed': _reactNativeBranch.BranchEvent.Purchase,
  'Product List Viewed': _reactNativeBranch.BranchEvent.ViewItems,
  'Product Added to Wishlist': _reactNativeBranch.BranchEvent.AddToWishlist,
  'Product Shared': _reactNativeBranch.BranchEvent.Share,
  'Cart Shared': _reactNativeBranch.BranchEvent.Share,
  'Products Searched': _reactNativeBranch.BranchEvent.Search
};
exports.mapEventNames = mapEventNames;
const mapEventProps = {
  order_id: 'transactionID',
  affilation: 'affiliation',
  currency: 'currency',
  revenue: 'revenue',
  coupon: 'coupon',
  shipping: 'shipping',
  tax: 'tax',
  query: 'searchQuery'
};
exports.mapEventProps = mapEventProps;
const mapProductProps = {
  sku: 'sku',
  name: 'productName',
  brand: 'productBrand',
  category: 'productCategory',
  variant: 'productVariant',
  quantity: 'quantity',
  price: 'price',
  image_url: 'contentImageUrl',
  url: 'canonicalUrl'
};
exports.mapProductProps = mapProductProps;
const transformMap = {
  event: value => {
    if (value in mapEventNames) {
      return mapEventNames[value];
    }

    return value;
  },
  products: value => {
    return value.map(item => {
      const data = {};

      for (const key in mapProductProps) {
        const newKey = mapProductProps[key];
        if (key in item) data[newKey] = item[key];
      }

      const {
        contentImageUrl,
        canonicalUrl,
        ...contentMetadata
      } = data;
      return {
        canonicalUrl,
        contentImageUrl,
        contentMetadata: { ...contentMetadata,
          customMetadata: {
            product_id: item.product_id
          }
        }
      };
    });
  }
};
exports.transformMap = transformMap;
//# sourceMappingURL=parameterMapping.js.map