"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createBranchEventWithProps = createBranchEventWithProps;

var _reactNativeBranch = _interopRequireWildcard(require("react-native-branch"));

var _parameterMapping = require("./parameterMapping");

function _getRequireWildcardCache(nodeInterop) { if (typeof WeakMap !== "function") return null; var cacheBabelInterop = new WeakMap(); var cacheNodeInterop = new WeakMap(); return (_getRequireWildcardCache = function (nodeInterop) { return nodeInterop ? cacheNodeInterop : cacheBabelInterop; })(nodeInterop); }

function _interopRequireWildcard(obj, nodeInterop) { if (!nodeInterop && obj && obj.__esModule) { return obj; } if (obj === null || typeof obj !== "object" && typeof obj !== "function") { return { default: obj }; } var cache = _getRequireWildcardCache(nodeInterop); if (cache && cache.has(obj)) { return cache.get(obj); } var newObj = {}; var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var key in obj) { if (key !== "default" && Object.prototype.hasOwnProperty.call(obj, key)) { var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null; if (desc && (desc.get || desc.set)) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } newObj.default = obj; if (cache) { cache.set(obj, newObj); } return newObj; }

function toJSONString(value) {
  if (typeof value === 'string') return value;
  return JSON.stringify(value);
}

async function createBranchEventWithProps(eventName, eventProps, isStandardBranchEvent) {
  const products = eventProps.product_id ? _parameterMapping.transformMap.products([eventProps]) : eventProps.products;
  const branchUniversalObjects = []; // for each product item, create a Branch Universal Objet

  if (Array.isArray(products)) {
    for (const item of products) {
      const product_id = item.contentMetadata.customMetadata.product_id;

      if (isStandardBranchEvent) {
        const buo = await _reactNativeBranch.default.createBranchUniversalObject(product_id, item);
        branchUniversalObjects.push(buo);
      } else {
        eventProps.customData = { ...eventProps.customData,
          [product_id]: toJSONString(item)
        };
      }
    }
  } else {
    // separate custom non-Branch entries before forwarding
    const customData = {};
    const branchData = {};

    for (const key in eventProps) {
      if (key in _parameterMapping.mapEventProps) branchData[key] = eventProps[key];
      customData[key] = toJSONString(eventProps[key]);
    }

    eventProps = { ...branchData,
      customData
    };
  }

  return new _reactNativeBranch.BranchEvent(eventName, isStandardBranchEvent ? branchUniversalObjects : undefined, eventProps);
}
//# sourceMappingURL=util.js.map