import { BranchEvent } from 'react-native-branch';
export const mapEventNames = {
  'Product Clicked': BranchEvent.ViewItem,
  'Product Viewed': BranchEvent.ViewItem,
  'Product Added': BranchEvent.AddToCart,
  'Product Reviewed': BranchEvent.Rate,
  'Checkout Started': BranchEvent.InitiatePurchase,
  'Promotion Viewed': BranchEvent.ViewAd,
  'Payment Info Entered': BranchEvent.AddPaymentInfo,
  'Order Completed': BranchEvent.Purchase,
  'Product List Viewed': BranchEvent.ViewItems,
  'Product Added to Wishlist': BranchEvent.AddToWishlist,
  'Product Shared': BranchEvent.Share,
  'Cart Shared': BranchEvent.Share,
  'Products Searched': BranchEvent.Search
};
export const mapEventProps = {
  order_id: 'transactionID',
  affilation: 'affiliation',
  currency: 'currency',
  revenue: 'revenue',
  coupon: 'coupon',
  shipping: 'shipping',
  tax: 'tax',
  query: 'searchQuery'
};
export const mapProductProps = {
  sku: 'sku',
  name: 'productName',
  brand: 'productBrand',
  category: 'productCategory',
  variant: 'productVariant',
  quantity: 'quantity',
  price: 'price',
  image_url: 'contentImageUrl',
  url: 'canonicalUrl'
};
export const transformMap = {
  event: value => {
    if (value in mapEventNames) {
      return mapEventNames[value];
    }

    return value;
  },
  products: value => {
    return value.map(item => {
      const data = {};

      for (const key in mapProductProps) {
        const newKey = mapProductProps[key];
        if (key in item) data[newKey] = item[key];
      }

      const {
        contentImageUrl,
        canonicalUrl,
        ...contentMetadata
      } = data;
      return {
        canonicalUrl,
        contentImageUrl,
        contentMetadata: { ...contentMetadata,
          customMetadata: {
            product_id: item.product_id
          }
        }
      };
    });
  }
};
//# sourceMappingURL=parameterMapping.js.map